@@ -15,9 +15,9 @@ import os, webbrowser, sys, time, logging, shutil, re
 log = logging.getLogger("App")
 
 # Internal version used by updater (if enabled)
-INTERNAL_VERSION		= "v0.8"
+INTERNAL_VERSION		= "v0.8.4"
 # Minimal Syncthing version supported by App
-MIN_ST_VERSION			= "0.12.0"
+MIN_ST_VERSION			= "0.13.0"
 
 COLOR_DEVICE			= "#707070"					# Dark-gray
 COLOR_DEVICE_SYNCING	= "#2A89C8"					# Blue
@@ -190,8 +190,8 @@ class App(Gtk.Application, TimerManager):
 	
 	def do_activate(self, *a):
 		if self.hide_window:
-			print
-			print _("Syncthing-GTK started and running in notification area")
+			log.info("")
+			log.info(_("Syncthing-GTK started and running in notification area"))
 			if not self.daemon is None:
 				self.daemon.set_refresh_interval(REFRESH_INTERVAL_TRAY)
 		else:
@@ -791,7 +791,7 @@ class App(Gtk.Application, TimerManager):
 			r.add_button(RIBar.build_button(_("_Add")), RESPONSE_FIX_FOLDER_ID)
 		self.show_error_box(r, {"nid" : nid, "rid" : rid} )
 	
-	def cb_syncthing_device_rejected(self, daemon, nid, address):
+	def cb_syncthing_device_rejected(self, daemon, nid, name, address):
 		# Remove port from address, it's random by default anyway
 		if "[" in address:
 			# IPv6 address
@@ -803,7 +803,8 @@ class App(Gtk.Application, TimerManager):
 			# Store as error message and don't display twice
 			return
 		self.error_messages.add((nid, address))
-		markup = _('Device "<b>%(device)s</b>" at IP "<b>%(ip)s</b>" wants to connect. Add new device?') % {
+		markup = _('Device "<b>%(name)s</b>" (%(device)s) at IP "<b>%(ip)s</b>" wants to connect. Add new device?') % {
+			'name' : name,
 			'device' : "<b>%s</b>" % nid,
 			'ip' : "<b>%s</b>" % address
 			}
@@ -945,8 +946,9 @@ class App(Gtk.Application, TimerManager):
 	
 	def cb_syncthing_folder_added(self, daemon, rid, r):
 		box = self.show_folder(
-			rid, r["path"], r["path"],
-			r["readOnly"], r["ignorePerms"], 
+			rid, r["label"], r["path"],
+			r["type"] == "readonly",
+			r["ignorePerms"], 
 			r["rescanIntervalS"],
 			sorted(
 				[ self.devices[n["deviceID"]] for n in r["devices"] if n["deviceID"] in self.devices ],
@@ -1173,11 +1175,6 @@ class App(Gtk.Application, TimerManager):
 		else:
 			self["window"].present()
 		self["menu-si-show"].set_label(_("Hide Window"))
-		if IS_WINDOWS:
-			# Change window size by 1px - this will cause bugged
-			# window border to reappear
-			self["window"].get_children()[0].set_visible(False)
-			GLib.idle_add(self["window"].get_children()[0].set_visible, True)
 	
 	def hide(self):
 		""" Hides main windows and 'Connecting' dialog, if displayed """
@@ -1263,14 +1260,28 @@ class App(Gtk.Application, TimerManager):
 			self.connect_dialog.hide()
 			self.connect_dialog.destroy()
 			self.connect_dialog = None
+			
+			if IS_WINDOWS:
+				# Force windows position on Windows - GTK 3.18 moves
+				# window to corner when connect_dialog disappears for
+				# some unexplainable reason
+				x, y = self["window"].get_position()
+				
+				def move_back():
+					self["window"].move(x, y)
+				GLib.idle_add(move_back)
 	
-	def show_folder(self, id, name, path, is_master, ignore_perms, rescan_interval, shared):
+	def show_folder(self, id, label, path, is_master, ignore_perms, rescan_interval, shared):
 		""" Shared is expected to be list """
 		display_path = path
 		if IS_WINDOWS:
 			if display_path.lower().replace("\\", "/").startswith(os.path.expanduser("~").lower()):
 				display_path = "~%s" % display_path[len(os.path.expanduser("~")):]
-		title = display_path if self.config["folder_as_path"] else id
+		title = id
+		if self.config["folder_as_path"]:
+			title = display_path
+		if label not in (None, ""):
+			title = label
 		if id in self.folders:
 			# Reuse existing box
 			box = self.folders[id]
@@ -1279,7 +1290,7 @@ class App(Gtk.Application, TimerManager):
 			# Create new box
 			box = InfoBox(self, title, Gtk.Image.new_from_icon_name("drive-harddisk", Gtk.IconSize.LARGE_TOOLBAR))
 			# Add visible lines
-			box.add_value("id",			"version.svg",	_("Folder ID"))
+			box.add_value("id",			"version.svg",	_("Folder ID"),			id)
 			box.add_value("path",		"folder.svg",	_("Path"))
 			box.add_value("global",		"global.svg",	_("Global State"),		"? items, ?B")
 			box.add_value("local",		"home.svg",		_("Local State"),		"? items, ?B")
@@ -1289,7 +1300,6 @@ class App(Gtk.Application, TimerManager):
 			box.add_value("rescan",		"rescan.svg",	_("Rescan Interval"))
 			box.add_value("shared",		"shared.svg",	_("Shared With"))
 			# Add hidden stuff
-			box.add_hidden_value("id", id)
 			box.add_hidden_value("b_master", is_master)
 			box.add_hidden_value("can_override", False)
 			box.add_hidden_value("devices", shared)
@@ -1319,7 +1329,7 @@ class App(Gtk.Application, TimerManager):
 		box.set_value("shared",	", ".join([ n.get_title() for n in shared ]))
 		box.set_value("b_master", is_master)
 		box.set_value("can_override", False)
-		box.set_visible("id",		self.config["folder_as_path"])
+		box.set_visible("id",		self.config["folder_as_path"] or label not in (None, ""))
 		box.set_visible("master",	is_master)
 		box.set_visible("ignore",	ignore_perms)
 		return box
@@ -1848,11 +1858,12 @@ class App(Gtk.Application, TimerManager):
 	
 	def cb_statusicon_notify_active(self, *a):
 		""" Called when the status icon changes its "inaccessible for sure" state """
-		# Show main window if the status icon is sure that no icon will be shown to the user
+		# Show main window if the status icon thinks that no icon is visible to the user
 		if not self.statusicon.get_active():
-			if not (IS_GNOME or IS_I3):
+			if not (IS_GNOME or IS_I3 or IS_MATE or IS_XFCE):
 				# Gnome sometimes lag on this, but always ends displaying icon later
 				# ... and i3 as well
+				# ... oh gods :'(
 				self.show()
 	
 	def cb_infobar_close(self, bar):
